@@ -32,10 +32,10 @@ function get_category_link($category_id) {
 		$category_nicename = $category->category_nicename;
 
 		if ( $parent = $category->category_parent )
-			$category_nicename = get_category_parents($parent, false, '/', true) . $category_nicename . '/';
+			$category_nicename = get_category_parents($parent, false, '/', true) . $category_nicename;
 
 		$catlink = str_replace('%category%', $category_nicename, $catlink);
-		$catlink = get_option('home') . trailingslashit($catlink);
+		$catlink = get_option('home') . user_trailingslashit($catlink, 'category');
 	}
 	return apply_filters('category_link', $catlink, $category_id);
 }
@@ -72,13 +72,17 @@ global $post, $category_cache, $blog_id;
 	$categories = $category_cache[$blog_id][$id];
 
 	if ( !empty($categories) )
-		sort($categories);
+		usort($categories, '_get_the_category_usort');
 	else
 		$categories = array();
 
 	return $categories;
 }
 
+function _get_the_category_usort($a, $b) {
+	return strcmp($a->category_name, $b->category_name);
+}
+
 function get_the_category_by_ID($cat_ID) {
 	$cat_ID = (int) $cat_ID;
 	$category = &get_category($cat_ID);
@@ -86,10 +90,13 @@ function get_the_category_by_ID($cat_ID) {
 }
 
 function get_the_category_list($separator = '', $parents='') {
+	global $wp_rewrite;
 	$categories = get_the_category();
 	if (empty($categories))
 		return apply_filters('the_category', __('Uncategorized'), $separator, $parents);
 
+	$rel = ( is_object($wp_rewrite) && $wp_rewrite->using_permalinks() ) ? 'rel="category tag"' : 'rel="category"';
+
 	$thelist = '';
 	if ( '' == $separator ) {
 		$thelist .= '<ul class="post-categories">';
@@ -99,17 +106,17 @@ function get_the_category_list($separator = '', $parents='') {
 				case 'multiple':
 					if ($category->category_parent)
 						$thelist .= get_category_parents($category->category_parent, TRUE);
-					$thelist .= '<a href="' . get_category_link($category->cat_ID) . '" title="' . sprintf(__("View all posts in %s"), $category->cat_name) . '" rel="category tag">'.$category->cat_name.'</a></li>';
+					$thelist .= '<a href="' . get_category_link($category->cat_ID) . '" title="' . sprintf(__("View all posts in %s"), $category->cat_name) . '" ' . $rel . '>' . $category->cat_name.'</a></li>';
 					break;
 				case 'single':
-					$thelist .= '<a href="' . get_category_link($category->cat_ID) . '" title="' . sprintf(__("View all posts in %s"), $category->cat_name) . ' rel="category tag">';
+					$thelist .= '<a href="' . get_category_link($category->cat_ID) . '" title="' . sprintf(__("View all posts in %s"), $category->cat_name) . '" ' . $rel . '>';
 					if ($category->category_parent)
 						$thelist .= get_category_parents($category->category_parent, FALSE);
 					$thelist .= $category->cat_name.'</a></li>';
 					break;
 				case '':
 				default:
-					$thelist .= '<a href="' . get_category_link($category->cat_ID) . '" title="' . sprintf(__("View all posts in %s"), $category->cat_name) . '" rel="category tag">'.$category->cat_name.'</a></li>';
+					$thelist .= '<a href="' . get_category_link($category->cat_ID) . '" title="' . sprintf(__("View all posts in %s"), $category->cat_name) . '" ' . $rel . '>' . $category->cat_name.'</a></li>';
 			}
 		}
 		$thelist .= '</ul>';
@@ -122,17 +129,17 @@ function get_the_category_list($separator = '', $parents='') {
 				case 'multiple':
 					if ( $category->category_parent )
 						$thelist .= get_category_parents($category->category_parent, TRUE);
-					$thelist .= '<a href="' . get_category_link($category->cat_ID) . '" title="' . sprintf(__("View all posts in %s"), $category->cat_name) . '" rel="category tag">'.$category->cat_name.'</a>';
+					$thelist .= '<a href="' . get_category_link($category->cat_ID) . '" title="' . sprintf(__("View all posts in %s"), $category->cat_name) . '" ' . $rel . '>' . $category->cat_name.'</a>';
 					break;
 				case 'single':
-					$thelist .= '<a href="' . get_category_link($category->cat_ID) . '" title="' . sprintf(__("View all posts in %s"), $category->cat_name) . '" rel="category tag">';
+					$thelist .= '<a href="' . get_category_link($category->cat_ID) . '" title="' . sprintf(__("View all posts in %s"), $category->cat_name) . '" ' . $rel . '>';
 					if ( $category->category_parent )
 						$thelist .= get_category_parents($category->category_parent, FALSE);
 					$thelist .= "$category->cat_name</a>";
 					break;
 				case '':
 				default:
-					$thelist .= '<a href="' . get_category_link($category->cat_ID) . '" title="' . sprintf(__("View all posts in %s"), $category->cat_name) . '" rel="category tag">'.$category->cat_name.'</a>';
+					$thelist .= '<a href="' . get_category_link($category->cat_ID) . '" title="' . sprintf(__("View all posts in %s"), $category->cat_name) . '" ' . $rel . '>' . $category->cat_name.'</a>';
 			}
 			++$i;
 		}
@@ -242,6 +249,12 @@ function wp_list_categories($args = '') {
 	} else {
 		global $wp_query;
 		
+		if( !empty($show_option_all) )
+			if ('list' == $style )  
+				$output .= '<li><a href="' .  get_bloginfo('url')  . '">' . $show_option_all . '</a></li>';
+			else
+				$output .= '<a href="' .  get_bloginfo('url')  . '">' . $show_option_all . '</a>';
+		
 		if ( is_category() )
 			$r['current_category'] = $wp_query->get_queried_object_id();
 
