@@ -8,7 +8,10 @@ function mysql2date($dateformatstring, $mysqlstring, $translate = true) {
 	if ( empty($m) ) {
 		return false;
 	}
-	$i = mktime(substr($m,11,2),substr($m,14,2),substr($m,17,2),substr($m,5,2),substr($m,8,2),substr($m,0,4));
+	$i = mktime( 
+		(int) substr( $m, 11, 2 ), (int) substr( $m, 14, 2 ), (int) substr( $m, 17, 2 ), 
+		(int) substr( $m, 5, 2 ), (int) substr( $m, 8, 2 ), (int) substr( $m, 0, 4 ) 
+	);
 
 	if( 'U' == $dateformatstring )
 		return $i;
@@ -203,20 +206,38 @@ function is_serialized_string($data) {
 function get_option($setting) {
 	global $wpdb;
 
-	$value = wp_cache_get($setting, 'options');
+	// Allow plugins to short-circuit options.
+	$pre = apply_filters( 'pre_option_' . $setting, false ); 
+	if ( $pre ) 
+		return $pre; 
 
-	if ( false === $value ) {
-		if ( defined('WP_INSTALLING') )
-			$wpdb->hide_errors();
-		$row = $wpdb->get_row("SELECT option_value FROM $wpdb->options WHERE option_name = '$setting' LIMIT 1");
-		if ( defined('WP_INSTALLING') )
-			$wpdb->show_errors();
+	// prevent non-existent options from triggering multiple queries
+	$notoptions = wp_cache_get('notoptions', 'options');
+	if ( isset($notoptions[$setting]) )
+		return false;
 
-		if( is_object( $row) ) { // Has to be get_row instead of get_var because of funkiness with 0, false, null values
-			$value = $row->option_value;
-			wp_cache_set($setting, $value, 'options');
-		} else {
-			return false;
+	$alloptions = wp_load_alloptions();
+
+	if ( isset($alloptions[$setting]) ) {
+		$value = $alloptions[$setting];
+	} else {
+		$value = wp_cache_get($setting, 'options');
+
+		if ( false === $value ) {
+			if ( defined('WP_INSTALLING') )
+				$wpdb->hide_errors();
+			$row = $wpdb->get_row("SELECT option_value FROM $wpdb->options WHERE option_name = '$setting' LIMIT 1");
+			if ( defined('WP_INSTALLING') )
+				$wpdb->show_errors();
+
+			if( is_object( $row) ) { // Has to be get_row instead of get_var because of funkiness with 0, false, null values
+				$value = $row->option_value;
+				wp_cache_add($setting, $value, 'options');
+			} else { // option does not exist, so we must cache its non-existence
+				$notoptions[$setting] = true;
+				wp_cache_set('notoptions', $notoptions, 'options');
+				return false;
+			}
 		}
 	}
 
@@ -230,6 +251,12 @@ function get_option($setting) {
 	return apply_filters( 'option_' . $setting, maybe_unserialize($value) );
 }
 
+function wp_protect_special_option($option) {
+	$protected = array('alloptions', 'notoptions');
+	if ( in_array($option, $protected) )
+		die(sprintf(__('%s is a protected WP option and may not be modified'), wp_specialchars($option)));
+}
+
 function form_option($option) {
 	echo attribute_escape(get_option($option));
 }
@@ -257,15 +284,35 @@ function get_alloptions() {
 	return apply_filters('all_options', $all_options);
 }
 
+function wp_load_alloptions() {
+	global $wpdb;
+
+	$alloptions = wp_cache_get('alloptions', 'options');
+
+	if ( !$alloptions ) {
+		$wpdb->hide_errors();
+		if ( !$alloptions_db = $wpdb->get_results("SELECT option_name, option_value FROM $wpdb->options WHERE autoload = 'yes'") )
+			$alloptions_db = $wpdb->get_results("SELECT option_name, option_value FROM $wpdb->options");
+		$wpdb->show_errors();
+		$alloptions = array();
+		foreach ( (array) $alloptions_db as $o )
+			$alloptions[$o->option_name] = $o->option_value;
+		wp_cache_add('alloptions', $alloptions, 'options');
+	}
+	return $alloptions;
+}
+
 function update_option($option_name, $newvalue) {
 	global $wpdb;
 
+	wp_protect_special_option($option_name);
+
 	if ( is_string($newvalue) )
 		$newvalue = trim($newvalue);
 
 	// If the new and old values are the same, no need to update.
 	$oldvalue = get_option($option_name);
-	if ( $newvalue == $oldvalue ) {
+	if ( $newvalue === $oldvalue ) {
 		return false;
 	}
 
@@ -274,10 +321,22 @@ function update_option($option_name, $newvalue) {
 		return true;
 	}
 
+	$notoptions = wp_cache_get('notoptions', 'options');
+	if ( isset($notoptions[$option_name]) ) {
+		unset($notoptions[$option_name]);
+		wp_cache_set('notoptions', $notoptions, 'options');
+	}
+
 	$_newvalue = $newvalue;
 	$newvalue = maybe_serialize($newvalue);
 
-	wp_cache_set($option_name, $newvalue, 'options');
+	$alloptions = wp_load_alloptions();
+	if ( isset($alloptions[$option_name]) ) {
+		$alloptions[$option_name] = $newvalue;
+		wp_cache_set('alloptions', $alloptions, 'options');
+	} else {
+		wp_cache_set($option_name, $newvalue, 'options');
+	}
 
 	$newvalue = $wpdb->escape($newvalue);
 	$option_name = $wpdb->escape($option_name);
@@ -293,13 +352,26 @@ function update_option($option_name, $newvalue) {
 function add_option($name, $value = '', $description = '', $autoload = 'yes') {
 	global $wpdb;
 
-	// Make sure the option doesn't already exist
-	if ( false !== get_option($name) )
-		return;
+	wp_protect_special_option($name);
+
+	// Make sure the option doesn't already exist we can check the cache before we ask for a db query
+	$notoptions = wp_cache_get('notoptions', 'options');
+	if ( isset($notoptions[$name]) ) {
+		unset($notoptions[$name]);
+		wp_cache_set('notoptions', $notoptions, 'options');
+	} elseif ( false !== get_option($name) ) {
+			return;
+	}
 
 	$value = maybe_serialize($value);
 
-	wp_cache_set($name, $value, 'options');
+	if ( 'yes' == $autoload ) {
+		$alloptions = wp_load_alloptions();
+		$alloptions[$name] = $value;
+		wp_cache_set('alloptions', $alloptions, 'options');
+	} else {
+		wp_cache_set($name, $value, 'options');
+	}
 
 	$name = $wpdb->escape($name);
 	$value = $wpdb->escape($value);
@@ -311,11 +383,22 @@ function add_option($name, $value = '', $description = '', $autoload = 'yes') {
 
 function delete_option($name) {
 	global $wpdb;
+
+	wp_protect_special_option($name);
+
 	// Get the ID, if no ID then return
-	$option_id = $wpdb->get_var("SELECT option_id FROM $wpdb->options WHERE option_name = '$name'");
-	if ( !$option_id ) return false;
+	$option = $wpdb->get_row("SELECT option_id, autoload FROM $wpdb->options WHERE option_name = '$name'");
+	if ( !$option->option_id ) return false;
 	$wpdb->query("DELETE FROM $wpdb->options WHERE option_name = '$name'");
-	wp_cache_delete($name, 'options');
+	if ( 'yes' == $option->autoload ) {
+		$alloptions = wp_load_alloptions();
+		if ( isset($alloptions[$name]) ) {
+			unset($alloptions[$name]);
+			wp_cache_set('alloptions', $alloptions, 'options');
+		}
+	} else {
+		wp_cache_delete($name, 'options');
+	}
 	return true;
 }
 
@@ -662,6 +745,7 @@ function clean_category_cache($id) {
 	wp_cache_delete($id, 'category');
 	wp_cache_delete('all_category_ids', 'category');
 	wp_cache_delete('get_categories', 'category');
+	delete_option('category_children');
 }
 
 /*
@@ -700,7 +784,7 @@ function add_query_arg() {
 		$protocol = '';
 	}
 
-	if ( strstr($uri, '?') ) {
+	if (strpos($uri, '?') !== false) {
 		$parts = explode('?', $uri, 2);
 		if ( 1 == count($parts) ) {
 			$base = '?';
@@ -709,7 +793,7 @@ function add_query_arg() {
 			$base = $parts[0] . '?';
 			$query = $parts[1];
 		}
-	} else if ( !empty($protocol) || strstr($uri, '/') ) {
+	} elseif (!empty($protocol) || strpos($uri, '/') !== false) {
 		$base = $uri . '?';
 		$query = '';
 	} else {
@@ -718,6 +802,9 @@ function add_query_arg() {
 	}
 
 	parse_str($query, $qs);
+	if ( get_magic_quotes_gpc() )
+		$qs = stripslashes_deep($qs); // parse_str() adds slashes if magicquotes is on.  See: http://php.net/parse_str
+	$qs = urlencode_deep($qs);
 	if ( is_array(func_get_arg(0)) ) {
 		$kayvees = func_get_arg(0);
 		$qs = array_merge($qs, $kayvees);
@@ -735,10 +822,10 @@ function add_query_arg() {
 				$ret .= "$k=$v";
 		}
 	}
+	$ret = trim($ret, '?');
 	$ret = $protocol . $base . $ret . $frag;
-	if ( get_magic_quotes_gpc() )
-		$ret = stripslashes($ret); // parse_str() adds slashes if magicquotes is on.  See: http://php.net/parse_str
-	return trim($ret, '?');
+	$ret = trim($ret, '?');
+	return $ret;
 }
 
 /*
@@ -828,10 +915,17 @@ function status_header( $header ) {
 	elseif ( 410 == $header )
 		$text = 'Gone';
 
-	if ( version_compare(phpversion(), '4.3.0', '>=') )
-		@header("HTTP/1.1 $header $text", true, $header);
-	else
-		@header("HTTP/1.1 $header $text");
+	$protocol = $_SERVER["SERVER_PROTOCOL"];
+	if ( ('HTTP/1.1' != $protocol) && ('HTTP/1.0' != $protocol) )
+		$protocol = 'HTTP/1.0';
+	$status_header = "$protocol $header $text";
+	$status_header = apply_filters('status_header', $status_header, $header, $text, $protocol);
+
+	if ( version_compare( phpversion(), '4.3.0', '>=' ) ) {
+		return @header( $status_header, true, $header );
+	} else {
+		return @header( $status_header );
+	}
 }
 
 function nocache_headers() {
@@ -859,46 +953,49 @@ function bool_from_yn($yn) {
 }
 
 function do_feed() {
+	global $wp_query;
+
 	$feed = get_query_var('feed');
 
 	// Remove the pad, if present.
 	$feed = preg_replace('/^_+/', '', $feed);
 
-	if ($feed == '' || $feed == 'feed')
-    	$feed = 'rss2';
-
-	$for_comments = false;
-	if ( 1 != get_query_var('withoutcomments') && ( is_singular() || get_query_var('withcomments') == 1 || $feed == 'comments-rss2' ) ) {
+	if ( $feed == '' || $feed == 'feed' )
 		$feed = 'rss2';
-		$for_comments = true;	
-	}
 
 	$hook = 'do_feed_' . $feed;
-	do_action($hook, $for_comments);
+	do_action($hook, $wp_query->is_comment_feed);
 }
 
 function do_feed_rdf() {
-	load_template(ABSPATH . 'wp-rdf.php');
+	load_template(ABSPATH . WPINC . '/feed-rdf.php');
 }
 
 function do_feed_rss() {
-	load_template(ABSPATH . 'wp-rss.php');
+	load_template(ABSPATH . WPINC . '/feed-rss.php');
 }
 
 function do_feed_rss2($for_comments) {
 	if ( $for_comments ) {
-		load_template(ABSPATH . 'wp-commentsrss2.php');
+		load_template(ABSPATH . WPINC . '/feed-rss2-comments.php');
 	} else {
-		load_template(ABSPATH . 'wp-rss2.php');
+		load_template(ABSPATH . WPINC . '/feed-rss2.php');
 	}
 }
 
-function do_feed_atom() {
-	load_template(ABSPATH . 'wp-atom.php');
+function do_feed_atom($for_comments) {
+	if ($for_comments) {
+		load_template(ABSPATH . WPINC . '/feed-atom-comments.php');
+	} else {
+		load_template(ABSPATH . WPINC . '/feed-atom.php');
+	}
 }
 
 function do_robots() {
+	header('Content-type: text/plain; charset=utf-8');
+
 	do_action('do_robotstxt');
+
 	if ( '0' == get_option('blog_public') ) {
 		echo "User-agent: *\n";
 		echo "Disallow: /\n";
@@ -913,7 +1010,9 @@ function is_blog_installed() {
 	$wpdb->hide_errors();
 	$installed = $wpdb->get_var("SELECT option_value FROM $wpdb->options WHERE option_name = 'siteurl'");
 	$wpdb->show_errors();
-	return $installed;
+
+	$install_status = !empty( $installed ) ? TRUE : FALSE;
+	return $install_status;
 }
 
 function wp_nonce_url($actionurl, $action = -1) {
@@ -1142,10 +1241,10 @@ function wp_explain_nonce($action) {
 		$trans['bulk']['comments'] = array(__('Are you sure you want to bulk modify comments?'), false);
 		$trans['moderate']['comments'] = array(__('Are you sure you want to moderate comments?'), false);
 
-		$trans['add']['bookmark'] = array(__('Are you sure you want to add this bookmark?'), false);
-		$trans['delete']['bookmark'] = array(__('Are you sure you want to delete this bookmark: &quot;%s&quot;?'), 'use_id');
-		$trans['update']['bookmark'] = array(__('Are you sure you want to edit this bookmark: &quot;%s&quot;?'), 'use_id');
-		$trans['bulk']['bookmarks'] = array(__('Are you sure you want to bulk modify bookmarks?'), false);
+		$trans['add']['bookmark'] = array(__('Are you sure you want to add this link?'), false);
+		$trans['delete']['bookmark'] = array(__('Are you sure you want to delete this link: &quot;%s&quot;?'), 'use_id');
+		$trans['update']['bookmark'] = array(__('Are you sure you want to edit this link: &quot;%s&quot;?'), 'use_id');
+		$trans['bulk']['bookmarks'] = array(__('Are you sure you want to bulk modify links?'), false);
 
 		$trans['add']['page'] = array(__('Are you sure you want to add this page?'), false);
 		$trans['delete']['page'] = array(__('Are you sure you want to delete this page: &quot;%s&quot;?'), 'get_the_title');
@@ -1215,18 +1314,43 @@ function wp_nonce_ays($action) {
 	wp_die($html, $title);
 }
 
-function wp_die($message, $title = '') {
+function wp_die( $message, $title = '' ) {
 	global $wp_locale;
 
+	if ( is_wp_error( $message ) ) {
+		if ( empty($title) ) {
+			$error_data = $message->get_error_data();
+			if ( is_array($error_data) && isset($error_data['title']) )
+				$title = $error_data['title'];
+		}
+		$errors = $message->get_error_messages();
+		switch ( count($errors) ) :
+		case 0 :
+			$message = '';
+			break;
+		case 1 :
+			$message = "<p>{$errors[0]}</p>";
+			break;
+		default :
+			$message = "<ul>\n\t\t<li>" . join( "</li>\n\t\t<li>", $errors ) . "</li>\n\t</ul>";
+			break;
+		endswitch;
+	} elseif ( is_string($message) ) {
+		$message = "<p>$message</p>";
+	}
+
+	if (strpos($_SERVER['PHP_SELF'], 'wp-admin') !== false)
+		$admin_dir = '';
+	else
+		$admin_dir = 'wp-admin/';
+
+	if ( !did_action('admin_head') ) :
 	header('Content-Type: text/html; charset=utf-8');
 
 	if ( empty($title) )
 		$title = __('WordPress &rsaquo; Error');
 
-	if ( strstr($_SERVER['PHP_SELF'], 'wp-admin') )
-		$admin_dir = '';
-	else
-		$admin_dir = 'wp-admin/';
+
 
 ?>
 <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
@@ -1235,20 +1359,34 @@ function wp_die($message, $title = '') {
 	<title><?php echo $title ?></title>
 	<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
 	<link rel="stylesheet" href="<?php echo $admin_dir; ?>install.css" type="text/css" />
-<?php if ( ('rtl' == $wp_locale->text_direction) ) : ?>
+<?php 
+if ( ( $wp_locale ) && ('rtl' == $wp_locale->text_direction) ) : ?>
 	<link rel="stylesheet" href="<?php echo $admin_dir; ?>install-rtl.css" type="text/css" />
 <?php endif; ?>
 </head>
 <body>
+<?php endif; ?>
 	<h1 id="logo"><img alt="WordPress" src="<?php echo $admin_dir; ?>images/wordpress-logo.png" /></h1>
-	<p><?php echo $message; ?></p>
+	<?php echo $message; ?>
+
 </body>
 </html>
 <?php
-
 	die();
 }
 
+function _config_wp_home($url = '') {
+	if ( defined( 'WP_HOME' ) ) 
+		return WP_HOME;
+	else return $url;
+}
+
+function _config_wp_siteurl($url = '') {
+	if ( defined( 'WP_SITEURL' ) ) 
+		return WP_SITEURL;
+	else return $url;
+}
+
 function _mce_set_direction() {
 	global $wp_locale;
 
@@ -1277,4 +1415,107 @@ function _mce_add_direction_buttons($input) {
 
 	return $input;
 }
-?>
+
+function smilies_init() {
+	global $wpsmiliestrans, $wp_smiliessearch, $wp_smiliesreplace;
+
+	// don't bother setting up smilies if they are disabled
+	if ( !get_option('use_smilies') )
+		return;
+
+	if (!isset($wpsmiliestrans)) {
+		$wpsmiliestrans = array(
+		':mrgreen:' => 'icon_mrgreen.gif',
+		':neutral:' => 'icon_neutral.gif',
+		':twisted:' => 'icon_twisted.gif',
+		  ':arrow:' => 'icon_arrow.gif',
+		  ':shock:' => 'icon_eek.gif',
+		  ':smile:' => 'icon_smile.gif',
+		    ':???:' => 'icon_confused.gif',
+		   ':cool:' => 'icon_cool.gif',
+		   ':evil:' => 'icon_evil.gif',
+		   ':grin:' => 'icon_biggrin.gif',
+		   ':idea:' => 'icon_idea.gif',
+		   ':oops:' => 'icon_redface.gif',
+		   ':razz:' => 'icon_razz.gif',
+		   ':roll:' => 'icon_rolleyes.gif',
+		   ':wink:' => 'icon_wink.gif',
+		    ':cry:' => 'icon_cry.gif',
+		    ':eek:' => 'icon_surprised.gif',
+		    ':lol:' => 'icon_lol.gif',
+		    ':mad:' => 'icon_mad.gif',
+		    ':sad:' => 'icon_sad.gif',
+		      '8-)' => 'icon_cool.gif',
+		      '8-O' => 'icon_eek.gif',
+		      ':-(' => 'icon_sad.gif',
+		      ':-)' => 'icon_smile.gif',
+		      ':-?' => 'icon_confused.gif',
+		      ':-D' => 'icon_biggrin.gif',
+		      ':-P' => 'icon_razz.gif',
+		      ':-o' => 'icon_surprised.gif',
+		      ':-x' => 'icon_mad.gif',
+		      ':-|' => 'icon_neutral.gif',
+		      ';-)' => 'icon_wink.gif',
+		       '8)' => 'icon_cool.gif',
+		       '8O' => 'icon_eek.gif',
+		       ':(' => 'icon_sad.gif',
+		       ':)' => 'icon_smile.gif',
+		       ':?' => 'icon_confused.gif',
+		       ':D' => 'icon_biggrin.gif',
+		       ':P' => 'icon_razz.gif',
+		       ':o' => 'icon_surprised.gif',
+		       ':x' => 'icon_mad.gif',
+		       ':|' => 'icon_neutral.gif',
+		       ';)' => 'icon_wink.gif',
+		      ':!:' => 'icon_exclaim.gif',
+		      ':?:' => 'icon_question.gif',
+		);
+	}
+
+	$siteurl = get_option('siteurl');
+	foreach ( (array) $wpsmiliestrans as $smiley => $img ) {
+		$wp_smiliessearch[] = '/(\s|^)'.preg_quote($smiley, '/').'(\s|$)/';
+		$smiley_masked = htmlspecialchars(trim($smiley), ENT_QUOTES);
+		$wp_smiliesreplace[] = " <img src='$siteurl/wp-includes/images/smilies/$img' alt='$smiley_masked' class='wp-smiley' /> ";
+	}
+}
+
+function wp_parse_args( $args, $defaults = '' ) {
+	if ( is_array($args) ) :
+		$r =& $args;
+	else :
+		parse_str( $args, $r );
+		if ( get_magic_quotes_gpc() )
+			$r = stripslashes_deep( $r );
+	endif;
+
+	if ( is_array($defaults) ) :
+		extract($defaults);
+		extract($r);
+		return compact(array_keys($defaults)); // only those options defined in $defaults
+	else :
+		return $r;
+	endif;
+}
+
+function wp_maybe_load_widgets() {
+	if ( !function_exists( 'dynamic_sidebar' ) ) {
+		require_once ABSPATH . WPINC . '/widgets.php';
+		add_action( '_admin_menu', 'wp_widgets_add_menu' );
+	}
+}
+
+function wp_widgets_add_menu() {
+	global $submenu;
+	$submenu['themes.php'][7] = array( __( 'Widgets' ), 'edit_themes', 'widgets.php' );
+	ksort($submenu['themes.php'], SORT_NUMERIC);
+}
+
+// For PHP 5.2, make sure all output buffers are flushed
+// before our singletons our destroyed.
+function wp_ob_end_flush_all()
+{
+	while ( @ob_end_flush() );
+}
+
+?>
\ No newline at end of file
