@@ -78,6 +78,7 @@ function get_theme_data( $theme_file ) {
 	$name = $theme_name[1];
 	$name = trim( $name );
 	$theme = $name;
+	$theme_uri = trim( $theme_uri[1] );
 
 	if ( '' == $author_uri[1] ) {
 		$author = trim( $author_name[1] );
@@ -85,7 +86,7 @@ function get_theme_data( $theme_file ) {
 		$author = '<a href="' . trim( $author_uri[1] ) . '" title="' . __('Visit author homepage') . '">' . trim( $author_name[1] ) . '</a>';
 	}
 
-	return array( 'Name' => $name, 'Title' => $theme, 'Description' => $description, 'Author' => $author, 'Version' => $version, 'Template' => $template[1], 'Status' => $status );
+	return array( 'Name' => $name, 'Title' => $theme, 'URI' => $theme_uri, 'Description' => $description, 'Author' => $author, 'Version' => $version, 'Template' => $template[1], 'Status' => $status );
 }
 
 function get_themes() {
@@ -162,6 +163,7 @@ function get_themes() {
 		$template    = $theme_data['Template'];
 		$stylesheet  = dirname($theme_file);
 
+		$screenshot = false;
 		foreach ( array('png', 'gif', 'jpg', 'jpeg') as $ext ) {
 			if (file_exists("$theme_root/$stylesheet/screenshot.$ext")) {
 				$screenshot = "screenshot.$ext";
@@ -186,7 +188,7 @@ function get_themes() {
 		if ( !file_exists("$theme_root/$template/index.php") ) {
 			$parent_dir = dirname(dirname($theme_file));
 			if ( file_exists("$theme_root/$parent_dir/$template/index.php") ) {
-				$template = "$parent_dir/$template"; 	
+				$template = "$parent_dir/$template"; 
 			} else {
 				$wp_broken_themes[$name] = array('Name' => $name, 'Title' => $title, 'Description' => __('Template is missing.'));
 				continue;
@@ -440,9 +442,9 @@ function get_theme_mod($name, $default = false) {
 	$mods = get_option("mods_$theme");
 
 	if ( isset($mods[$name]) )
-		return $mods[$name];
+		return apply_filters( "theme_mod_$name", $mods[$name] );
 
-	return sprintf($default, get_template_directory_uri());
+	return apply_filters( "theme_mod_$name", sprintf($default, get_template_directory_uri()) );
 }
 
 function set_theme_mod($name, $value) {
@@ -484,7 +486,7 @@ function get_header_textcolor() {
 }
 
 function header_textcolor() {
-	echo get_header_textcolor();	
+	echo get_header_textcolor();
 }
 
 function get_header_image() {
@@ -492,7 +494,7 @@ function get_header_image() {
 }
 
 function header_image() {
-	echo get_header_image();	
+	echo get_header_image();
 }
 
 function add_custom_image_header($header_callback, $admin_header_callback) {
